@@ -8,7 +8,7 @@ from threading import Thread
 from scrapy.commands import ScrapyCommand
 from scrapy.http import Request
 from scrapy.shell import Shell
-from scrapy.utils.spider import spidercls_for_request, DefaultSpider
+from scrapy.utils.spider import DefaultSpider, spidercls_for_request
 from scrapy.utils.url import guess_scheme
 
 
@@ -16,9 +16,9 @@ class Command(ScrapyCommand):
 
     requires_project = False
     default_settings = {
-        'KEEP_ALIVE': True,
-        'LOGSTATS_INTERVAL': 0,
-        'DUPEFILTER_CLASS': 'scrapy.dupefilters.BaseDupeFilter',
+        "KEEP_ALIVE": True,
+        "LOGSTATS_INTERVAL": 0,
+        "DUPEFILTER_CLASS": "scrapy.dupefilters.BaseDupeFilter",
     }
 
     def syntax(self):
@@ -28,17 +28,26 @@ class Command(ScrapyCommand):
         return "Interactive scraping console"
 
     def long_desc(self):
-        return ("Interactive console for scraping the given url or file. "
-                "Use ./file.html syntax or full path for local file.")
+        return (
+            "Interactive console for scraping the given url or file. "
+            "Use ./file.html syntax or full path for local file."
+        )
 
     def add_options(self, parser):
         ScrapyCommand.add_options(self, parser)
-        parser.add_option("-c", dest="code",
-                          help="evaluate the code in the shell, print the result and exit")
-        parser.add_option("--spider", dest="spider",
-                          help="use this spider")
-        parser.add_option("--no-redirect", dest="no_redirect", action="store_true", default=False,
-                          help="do not handle HTTP 3xx status codes and print response as-is")
+        parser.add_argument(
+            "-c",
+            dest="code",
+            help="evaluate the code in the shell, print the result and exit",
+        )
+        parser.add_argument("--spider", dest="spider", help="use this spider")
+        parser.add_argument(
+            "--no-redirect",
+            dest="no_redirect",
+            action="store_true",
+            default=False,
+            help="do not handle HTTP 3xx status codes and print response as-is",
+        )
 
     def update_vars(self, vars):
         """You can use this function to update the Scrapy objects that will be
@@ -58,8 +67,9 @@ class Command(ScrapyCommand):
         if opts.spider:
             spidercls = spider_loader.load(opts.spider)
         elif url:
-            spidercls = spidercls_for_request(spider_loader, Request(url),
-                                              spidercls, log_multiple=True)
+            spidercls = spidercls_for_request(
+                spider_loader, Request(url), spidercls, log_multiple=True
+            )
 
         # The crawler is created this way since the Shell manually handles the
         # crawling engine, so the set up in the crawl method won't work
@@ -74,7 +84,9 @@ class Command(ScrapyCommand):
         shell.start(url=url, redirect=not opts.no_redirect)
 
     def _start_crawler_thread(self):
-        t = Thread(target=self.crawler_process.start,
-                   kwargs={'stop_after_crawl': False})
+        t = Thread(
+            target=self.crawler_process.start,
+            kwargs={"stop_after_crawl": False, "install_signal_handlers": False},
+        )
         t.daemon = True
         t.start()
