@@ -6,20 +6,19 @@ See documentation in docs/topics/spider-middleware.rst
 
 import logging
 
-from scrapy.http import Request
 from scrapy.exceptions import NotConfigured
+from scrapy.http import Request
 
 logger = logging.getLogger(__name__)
 
 
 class UrlLengthMiddleware:
-
     def __init__(self, maxlength):
         self.maxlength = maxlength
 
     @classmethod
     def from_settings(cls, settings):
-        maxlength = settings.getint('URLLENGTH_LIMIT')
+        maxlength = settings.getint("URLLENGTH_LIMIT")
         if not maxlength:
             raise NotConfigured
         return cls(maxlength)
@@ -36,9 +35,11 @@ class UrlLengthMiddleware:
         if isinstance(request, Request) and len(request.url) > self.maxlength:
             logger.info(
                 "Ignoring link (url length > %(maxlength)d): %(url)s ",
-                {'maxlength': self.maxlength, 'url': request.url},
-                extra={'spider': spider}
+                {"maxlength": self.maxlength, "url": request.url},
+                extra={"spider": spider},
+            )
+            spider.crawler.stats.inc_value(
+                "urllength/request_ignored_count", spider=spider
             )
-            spider.crawler.stats.inc_value('urllength/request_ignored_count', spider=spider)
             return False
         return True
